from cpl_core.configuration import ConfigurationABC

from bot_core.configuration.feature_flags_settings import FeatureFlagsSettings
from bot_data.abc.server_config_repository_abc import ServerConfigRepositoryABC
from bot_data.abc.technician_config_repository_abc import TechnicianConfigRepositoryABC
from bot_data.model.server import Server
from bot_data.model.technician_config import TechnicianConfig


class ConfigService:
    def __init__(
        self,
        config: ConfigurationABC,
        technician_config_repo: TechnicianConfigRepositoryABC,
        server_config_repo: ServerConfigRepositoryABC,
    ):
        self._config = config
        self._technician_config_repo = technician_config_repo
        self._server_config_repo = server_config_repo

    def reload_technician_config(self):
        technician_config = self._technician_config_repo.get_technician_config()
        self._config.add_configuration(TechnicianConfig, technician_config)
        self._config.add_configuration(FeatureFlagsSettings, FeatureFlagsSettings(**technician_config.feature_flags))

    def reload_server_config(self, server: Server):
        server_config = self._server_config_repo.get_server_config_by_server(server.id)
        self._config.add_configuration(
            f"{type(server_config).__name__}_{server_config.server.discord_id}", server_config
        )
